==> react-gui-common-1.3.172.tgz: package/src/components/validation/VerifySignature.js <==
/* eslint-disable react/jsx-max-props-per-line */
/* eslint-disable max-len */
import React, { Component } from 'react';

import { Button } from 'primereact/button';
import { Dialog } from 'primereact/dialog';
import PropTypes from 'prop-types';

export const verifySignature = (
	archivePackageFile,
	signatureFile,
	onSignatureVerified,
	onVerificationError,
	debug,
	devMode,
	devSzafirUri
) => {
	console.log('+++ archivePackageFile:', archivePackageFile);
	console.log('+++ signatureFile:', signatureFile);

	const signatureReader = new FileReader();
	const archivePackageReader = new FileReader();
	signatureReader.readAsBinaryString(signatureFile);
	signatureReader.onloadend = function() {
		const signatureData = signatureReader.result;
		const signatureId = getSignatureId(signatureData);
		const buff = new Buffer(signatureData);
		const signatureB64 = buff.toString('base64');
		// console.log(signatureB64);

		archivePackageReader.readAsArrayBuffer(archivePackageFile);
		archivePackageReader.onloadend = function(event) {
			const data = event.target.result;
			console.log(data);
			const archivePackageB64 = arrayBufferToBase64(data);
			const task = generateSzafirVerifyTask(signatureB64, signatureId, archivePackageB64);
			// console.log(task);

			configureSzafir(task, onSignatureVerified, onVerificationError, debug, devMode, devSzafirUri);
		};
	};

	function getSignatureId(signature) {
		const parser = new DOMParser();
		const signatureXml = parser.parseFromString(signature, 'text/xml');
		console.log('signatureXml', signatureXml);
		if (signatureXml) {
			const idPath = '//ds:Signature/@Id';
			const nodes = signatureXml.evaluate(
				idPath,
				signatureXml,
				resolveNamespace,
				XPathResult.ANY_TYPE,
				null
			);
			if (nodes) {
				const idIterator = nodes.iterateNext();
				if (idIterator) {
					const id = idIterator.nodeValue;
					console.log(`getSignatureId, id=${id}`);
					return id;
				}
			}
		}
		console.log('getSignatureId: ERROR - can not read Id!');
		return null;
	}
};

function handleError(error, onVerificationError) {
	if (onVerificationError) {
		onVerificationError(error);
	}
}

function userUnloadSzafir(onVerificationError) {
	console.log('Start unloading SZAFIR SDK...');
	// eslint-disable-next-line no-undef
	SZAFIR_SDK.unloadSzafir(
		() => console.log('szafir has been unloaded...'),
		error => handleError(error, onVerificationError)
	);
}

function handleSignatureVerified(result, onSignatureVerified, onVerificationError) {
	console.log('handleSignatureVerified: result:', result);
	userUnloadSzafir(onVerificationError);
	const parser = new DOMParser();
	const xmlDoc = parser.parseFromString(result, 'text/xml');
	const codePath =
		'/TaskList/VerifyingTask/VerifyingTaskItem[1]/Signature/VerificationResult/Result/@code';
	let nodes = xmlDoc.evaluate(codePath, xmlDoc, null, XPathResult.ANY_TYPE, null);
	let it = nodes.iterateNext();
	const code = it ? it.nodeValue : undefined;

	const codeDescPath =
		'/TaskList/VerifyingTask/VerifyingTaskItem[1]/Signature/VerificationResult/Result/text()';
	nodes = xmlDoc.evaluate(codeDescPath, xmlDoc, null, XPathResult.ANY_TYPE, null);
	it = nodes.iterateNext();
	const codeDesc = it ? it.nodeValue : undefined;

	const descPath =
		'/TaskList/VerifyingTask/VerifyingTaskItem[1]/Signature/VerificationResult/Description/text()';
	nodes = xmlDoc.evaluate(descPath, xmlDoc, null, XPathResult.ANY_TYPE, null);
	it = nodes.iterateNext();
	const desc = it ? it.nodeValue : undefined;

	const additionalCodePath =
		'/TaskList/VerifyingTask/VerifyingTaskItem[1]/Signature/VerificationResult/Description/@code';
	nodes = xmlDoc.evaluate(additionalCodePath, xmlDoc, null, XPathResult.ANY_TYPE, null);
	it = nodes.iterateNext();
	const additionalCode = it ? it.nodeValue : undefined;

	const subjectPath =
		'/TaskList/VerifyingTask/VerifyingTaskItem[1]/Signature/VerificationResult/SigningCertificate/Subject/text()';
	nodes = xmlDoc.evaluate(subjectPath, xmlDoc, null, XPathResult.ANY_TYPE, null);
	it = nodes.iterateNext();
	const subject = it ? it.nodeValue : undefined;

	const issuerPath =
		'/TaskList/VerifyingTask/VerifyingTaskItem[1]/Signature/VerificationResult/SigningCertificate/Issuer/text()';
	nodes = xmlDoc.evaluate(issuerPath, xmlDoc, null, XPathResult.ANY_TYPE, null);
	it = nodes.iterateNext();
	const issuer = it ? it.nodeValue : undefined;

	const certIdPath =
		'/TaskList/VerifyingTask/VerifyingTaskItem[1]/Signature/VerificationResult/SignatureID/text()';
	nodes = xmlDoc.evaluate(certIdPath, xmlDoc, null, XPathResult.ANY_TYPE, null);
	it = nodes.iterateNext();
	const certId = it ? it.nodeValue : undefined;

	const signDatePath =
		'/TaskList/VerifyingTask/VerifyingTaskItem[1]/Signature/VerificationResult/SigningTime/text()';
	nodes = xmlDoc.evaluate(signDatePath, xmlDoc, null, XPathResult.ANY_TYPE, null);
	it = nodes.iterateNext();
	const signDate = it ? it.nodeValue : undefined;

	console.log(
		`code: ${code}, codeDesc: ${codeDesc}, desc=${desc}, additionalCode=${additionalCode}`
	);

	if (onSignatureVerified) {
		onSignatureVerified({
			code,
			codeDesc,
			additionalCode,
			desc,
			subject,
			issuer,
			certId,
			signDate,
		});
	}
}

function szafirDoTaskList(task, onSignatureVerified, onVerificationError) {
	console.log('szafirDoTaskList...');
	// eslint-disable-next-line no-undef
	SZAFIR_SDK.doTaskListNoWindow(
		task,
		result => handleSignatureVerified(result, onSignatureVerified, onVerificationError),
		error => handleError(error, onVerificationError)
	);
}

function generateSzafirVerifyTask(signatureB64, signatureId, archivePackageB64) {
	return `<?xml version="1.0" encoding="UTF-8"?>
	<TaskList><VerifyingTask><XAdESForm>XAdES-BES</XAdESForm>
	<PKCS7Form>PKCS#7</PKCS7Form>
	<VerifyingTaskItem><SignatureContainer><Base64Binary>${signatureB64}</Base64Binary>
	</SignatureContainer>
	<Signature Id="ID-c97bbd1d-f756-4c59-aca8-aa7cef24158b" URI="${signatureId}"><Format>XAdES-BES</Format>
	<SignedData>
	<Base64Binary>${archivePackageB64}</Base64Binary>
	</SignedData>
	<VerificationProperties><TimeSource><SystemTime></SystemTime>
	</TimeSource>
	</VerificationProperties>
	</Signature>
	</VerifyingTaskItem>
	</VerifyingTask>
	</TaskList>`;
}

function resolveNamespace(ns) {
	if (ns === 'ds') {
		return 'http://www.w3.org/2000/09/xmldsig#';
	} else {
		return null;
	}
}

function arrayBufferToBase64(buffer) {
	let binary = '';
	const bytes = new Uint8Array(buffer);
	const len = bytes.byteLength;
	for (let i = 0; i < len; i++) {
		binary += String.fromCharCode(bytes[i]);
	}
	return window.btoa(binary);
}

function configureSzafir(
	task,
	onSignatureVerified,
	onVerificationError,
	debug,
	devMode,
	devSzafirUri
) {
	console.log('configureSzafir...');
	// eslint-disable-next-line no-undef
	const SZAFIR = SZAFIR_SDK;

	SZAFIR.config({
		sdk_location_url: devMode ? `${devSzafirUri}/o/rest-api/szafir/` : '/o/rest-api/szafir/',
		versions_file: 'versions.xml',
		document_dependencies_folder: 'somewhere',
		series_authorization: true,
		onError: error => {
			console.log('szafirErrorCallback, error:', error);
			alert('[***** Błąd Szafir SDK *****]\n\n', error);
			if (onVerificationError) {
				onVerificationError(error);
			}
		},
		onErrorNoExtension: () => onVerificationError('noExtension'),
		onErrorNoHostApp: () => onVerificationError('noHostApp'),
		debug,
	});
	console.log('SZAFIR_SDK.version:', SZAFIR.version);
	console.log('SZAFIR_SDK.initialized', SZAFIR.isExtInitialized());
	initSzafirApplet(devMode, devSzafirUri);
	userLoadSzafir(task, onSignatureVerified, onVerificationError, devMode, devSzafirUri);
}

function initSzafirApplet(devMode, devSzafirUri) {
	// eslint-disable-next-line no-undef
	const SZAFIR = SZAFIR_SDK;
	if (SZAFIR.isModeApplet()) {
		const archive = devMode
			? `${devSzafirUri}/o/rest-api/szafir/cryptoapplet.jar`
			: 'o/rest-api/szafir/cryptoapplet.jar';
		const libDir = devMode ? `${devSzafirUri}/o/rest-api/szafir/` : '/o/rest-api/szafir';

		document.getElementById(
			'szafirApplet'
		).innerHTML = `${`<applet name="CA" code="pl.com.kir.crypto.applet.CryptoApplet" archive="${archive}" WIDTH="0" HEIGHT="0">\n` +
			'<param name="Server-Library" value="'}${libDir}"/>Your browser does not understand Java.</applet>`;
	}
}

function userLoadSzafir(task, onSignatureVerified, onVerificationError, devMode, devSzafirUri) {
	console.log('Start loading SZAFIR MODULE...');
	// eslint-disable-next-line no-undef
	SZAFIR_SDK.loadSzafir(
		() =>
			szafirStartComponentURI(
				task,
				onSignatureVerified,
				onVerificationError,
				devMode,
				devSzafirUri
			),
		error => handleError(error, onVerificationError)
	);
}

function szafirStartComponentURI(
	task,
	onSignatureVerified,
	onVerificationError,
	devMode,
	devSzafirUri
) {
	console.log('Start loading SZAFIR SETTINGS...4');
	// eslint-disable-next-line no-undef
	if ($('#SZAFIRSDK_APPLET_OBJECT').length > 0) {
		console.log('SZAFIR_SDK.mode: APPLET');
	} else {
		console.log('SZAFIR_SDK.mode: WEB-MODULE');
	}
	// eslint-disable-next-line max-len
	let settingsUri =
		'/o/rest-api/szafir/settings_files/settings_cryptoproviders_wszystkie_centra.xml';
	if (devMode) {
		settingsUri = `${devSzafirUri}${settingsUri}`;
	}
	// eslint-disable-next-line no-undef
	SZAFIR_SDK.startComponentURI(
		settingsUri,
		() => szafirDoTaskList(task, onSignatureVerified, onVerificationError),
		error => handleError(error, onVerificationError)
	);
}

export class NoSzafirExtDialog extends Component {
	constructor(props) {
		super(props);
	}

	hideNoEtxDialog(e) {
		const { onClose } = this.props;
		if (e !== undefined) {
			e.preventDefault();
		}
		if (onClose) {
			onClose();
		}
	}

	render() {
		const { visible } = this.props;
		const noExtDialogFooter = (
			<div>
				<Button label="Zamknij" icon="pi pi-check" onClick={e => this.hideNoEtxDialog(e)} />
			</div>
		);
		return (
			<Dialog
				ariaCloseIconLabel="Zamknij okno dialogowe"
				key="noExtDialog"
				visible={visible}
				style={{ width: '40vw' }}
				modal
				closable
				header="Ostrzeżenie - Brak rozszerzenia Szafir SDK"
				onHide={() => this.hideNoEtxDialog()}
				footer={noExtDialogFooter}
			>
				Niniejsza strona wykorzystuje komponenty podpisu elektronicznego&nbsp;
				<a tabIndex="0" href="http://elektronicznypodpis.pl/" target="_blank">
					Szafir SDK
				</a>
				&nbsp;
				<a tabIndex="0" href="http://www.kir.pl/" target="_blank">
					Krajowej Izby Rozliczeniowej S.A.
				</a>
				<br />W wersji dla przeglądarek <b>Google Chrome</b>, <b>Opera</b> i&nbsp;
				<b>Mozilla Firefox od wersji 52</b> wymagana jest instalacja dedykowanego rozszerzenia&nbsp;
				<b>Podpis elektroniczny Szafir SDK</b> oraz aplikacji udostępniającej funkcje podpisu
				elektronicznego.
				<p id="szafirsdk-link-buttons">
					<a
						tabIndex="0"
						id="szafirsdk-link-extension"
						// eslint-disable-next-line no-undef
						href={SZAFIR_SDK.getExtLink()}
						target="_blank"
					>
						Instalacja rozszerzenia z Web Store
					</a>
				</p>
				<div>
					<b>Uwaga:</b> Po zainstalowaniu rozszerzenia należy przeładować bieżącą stronę!
				</div>
			</Dialog>
		);
	}
}

NoSzafirExtDialog.defaultProps = {
	visible: false,
};

NoSzafirExtDialog.propTypes = {
	onClose: PropTypes.func.isRequired,
	visible: PropTypes.bool.isRequired,
};

export class NoSzafirHostDialog extends Component {
	constructor(props) {
		super(props);
	}

	hideNoHostDialog(e) {
		const { onClose } = this.props;
		if (e !== undefined) {
			e.preventDefault();
		}
		if (onClose) {
			onClose();
		}
	}

	render() {
		const { visible } = this.props;
		const noHostDialogFooter = (
			<div>
				<Button label="Zamknij" icon="pi pi-check" onClick={e => this.hideNoHostDialog(e)} />
			</div>
		);
		let appLinkWin = undefined;
		let appLinkLinux = undefined;
		// eslint-disable-next-line no-undef
		const SZAFIR = SZAFIR_SDK;
		if (SZAFIR.getAppLinks() !== undefined) {
			appLinkWin = SZAFIR.getAppLinks().windows;
			appLinkLinux = SZAFIR.getAppLinks().linux;
		}
		return (
			<Dialog
				ariaCloseIconLabel="Zamknij okno dialogowe"
				key="noHostDialog"
				visible={visible}
				style={{ width: '40vw' }}
				modal
				closable
				header="Ostrzeżenie - Brak aplikacji Szafir Host"
				onHide={() => this.hideNoHostDialog()}
				footer={noHostDialogFooter}
			>
				{!SZAFIR.isHostUpdateRequired() ? (
					<div id="szafirsdk-hostapp-install">
						Przeglądarka wymaga zainstalowania dedykowanej aplikacji&nbsp;
						<b>Szafir Host</b> umożliwiającej składanie podpisu elektronicznego.
					</div>
				) : null}

				{SZAFIR.isHostUpdateRequired() ? (
					<div id="szafirsdk-hostapp-update" style={{ color: 'Red' }}>
						Posiadasz nieaktualną wersję aplikacji <b>Szafir Host</b>&nbsp; używaną przez
						przeglądarkę do składania podpisu elektronicznego!!!
					</div>
				) : null}
				<p id="szafirsdk-nohost-link-buttons">
					<a tabIndex="0" style={{ maringBottom: '2px' }} href={appLinkWin} target="_blank">
						Pobierz Szafir Host dla Windows
					</a>
					<br />
					<a
						tabIndex="0"
						id="szafirsdk-link-installer-ux"
						href={appLinkLinux}
						style={{ maringBottom: '2px' }}
						target="_blank"
					>
						Pobierz Szafir Host dla Linux/Mac OS
					</a>
				</p>
				<div>
					<b>Uwaga:</b> Po zainstalowaniu aplikacji Szafir Host należy przeładować bieżącą stronę!
				</div>
				<div
					style={{ backgroundColor: '#78BED7', color: 'White', padding: '4px', marginTop: '4px' }}
				>
					Jeżeli aplikacja została prawidłowo zainstalowana i mimo tego nadal&nbsp; pojawia się
					niniejszy komunikat, należy sprawdzić czy na komputerze&nbsp; zainstalowane jest
					środowisko uruchomieniowe Java JRE.
					<br />
					Środowisko Java JRE można pobrać i zainstalować z lokalizacji:&nbsp;
					<a tabIndex="0" href="https://www.java.com/download/" target="_blank">
						Java JRE
					</a>
				</div>
			</Dialog>
		);
	}
}

NoSzafirHostDialog.defaultProps = {
	visible: false,
};

NoSzafirHostDialog.propTypes = {
	onClose: PropTypes.func.isRequired,
	visible: PropTypes.bool.isRequired,
};

==> react-gui-common-1.3.265.tgz: package/src/components/validation/VerifySignature.js <==
/* eslint-disable react/jsx-max-props-per-line */
/* eslint-disable max-len */
import React, { Component } from 'react';

import { Button } from 'primereact/button';
import { Dialog } from 'primereact/dialog';
import PropTypes from 'prop-types';

export const verifySignature = (
	archivePackageFile,
	signatureFile,
	onSignatureVerified,
	onVerificationError,
	debug,
	devMode,
	devSzafirUri
) => {
	console.log('+++ archivePackageFile:', archivePackageFile);
	console.log('+++ signatureFile:', signatureFile);

	const signatureReader = new FileReader();
	const archivePackageReader = new FileReader();
	signatureReader.readAsText(signatureFile);
	signatureReader.onloadend = function(event) {
		const signatureData = event.target.result;
		const signatureId = getSignatureId(signatureData);
		const buff = new Buffer(signatureData);
		const signatureB64 = buff.toString('base64');
		// console.log(signatureB64);

		archivePackageReader.readAsArrayBuffer(archivePackageFile);
		archivePackageReader.onloadend = function(event) {
			const data = event.target.result;
			console.log(data);
			const archivePackageB64 = arrayBufferToBase64(data);
			const task = generateSzafirVerifyTask(signatureB64, signatureId, archivePackageB64);
			// console.log(task);

			configureSzafir(task, onSignatureVerified, onVerificationError, debug, devMode, devSzafirUri);
		};
	};

	function getSignatureId(signature) {
		const parser = new DOMParser();
		const signatureXml = parser.parseFromString(signature, 'text/xml');
		console.log('signatureXml', signatureXml);
		if (signatureXml) {
			const idPath = '//ds:Signature/@Id';
			const nodes = signatureXml.evaluate(
				idPath,
				signatureXml,
				resolveNamespace,
				XPathResult.ANY_TYPE,
				null
			);
			if (nodes) {
				const idIterator = nodes.iterateNext();
				if (idIterator) {
					const id = idIterator.nodeValue;
					console.log(`getSignatureId, id=${id}`);
					return id;
				}
			}
		}
		console.log('getSignatureId: ERROR - can not read Id!');
		return null;
	}
};

function handleError(error, onVerificationError) {
	if (onVerificationError) {
		onVerificationError(error);
	}
}

function userUnloadSzafir(onVerificationError) {
	console.log('Start unloading SZAFIR SDK...');
	// eslint-disable-next-line no-undef
	SZAFIR_SDK.unloadSzafir(
		() => console.log('szafir has been unloaded...'),
		error => handleError(error, onVerificationError)
	);
}

function handleSignatureVerified(result, onSignatureVerified, onVerificationError) {
	console.log('handleSignatureVerified: result:', result);
	userUnloadSzafir(onVerificationError);
	const parser = new DOMParser();
	const xmlDoc = parser.parseFromString(result, 'text/xml');
	const codePath =
		'/TaskList/VerifyingTask/VerifyingTaskItem[1]/Signature/VerificationResult/Result/@code';
	let nodes = xmlDoc.evaluate(codePath, xmlDoc, null, XPathResult.ANY_TYPE, null);
	let it = nodes.iterateNext();
	const code = it ? it.nodeValue : undefined;

	const codeDescPath =
		'/TaskList/VerifyingTask/VerifyingTaskItem[1]/Signature/VerificationResult/Result/text()';
	nodes = xmlDoc.evaluate(codeDescPath, xmlDoc, null, XPathResult.ANY_TYPE, null);
	it = nodes.iterateNext();
	const codeDesc = it ? it.nodeValue : undefined;

	const descPath =
		'/TaskList/VerifyingTask/VerifyingTaskItem[1]/Signature/VerificationResult/Description/text()';
	nodes = xmlDoc.evaluate(descPath, xmlDoc, null, XPathResult.ANY_TYPE, null);
	it = nodes.iterateNext();
	const desc = it ? it.nodeValue : undefined;

	const additionalCodePath =
		'/TaskList/VerifyingTask/VerifyingTaskItem[1]/Signature/VerificationResult/Description/@code';
	nodes = xmlDoc.evaluate(additionalCodePath, xmlDoc, null, XPathResult.ANY_TYPE, null);
	it = nodes.iterateNext();
	const additionalCode = it ? it.nodeValue : undefined;

	const subjectPath =
		'/TaskList/VerifyingTask/VerifyingTaskItem[1]/Signature/VerificationResult/SigningCertificate/Subject/text()';
	nodes = xmlDoc.evaluate(subjectPath, xmlDoc, null, XPathResult.ANY_TYPE, null);
	it = nodes.iterateNext();
	const subject = it ? it.nodeValue : undefined;

	const issuerPath =
		'/TaskList/VerifyingTask/VerifyingTaskItem[1]/Signature/VerificationResult/SigningCertificate/Issuer/text()';
	nodes = xmlDoc.evaluate(issuerPath, xmlDoc, null, XPathResult.ANY_TYPE, null);
	it = nodes.iterateNext();
	const issuer = it ? it.nodeValue : undefined;

	const certIdPath =
		'/TaskList/VerifyingTask/VerifyingTaskItem[1]/Signature/VerificationResult/SignatureID/text()';
	nodes = xmlDoc.evaluate(certIdPath, xmlDoc, null, XPathResult.ANY_TYPE, null);
	it = nodes.iterateNext();
	const certId = it ? it.nodeValue : undefined;

	const signDatePath =
		'/TaskList/VerifyingTask/VerifyingTaskItem[1]/Signature/VerificationResult/SigningTime/text()';
	nodes = xmlDoc.evaluate(signDatePath, xmlDoc, null, XPathResult.ANY_TYPE, null);
	it = nodes.iterateNext();
	const signDate = it ? it.nodeValue : undefined;

	console.log(
		`code: ${code}, codeDesc: ${codeDesc}, desc=${desc}, additionalCode=${additionalCode}`
	);

	if (onSignatureVerified) {
		onSignatureVerified({
			code,
			codeDesc,
			additionalCode,
			desc,
			subject,
			issuer,
			certId,
			signDate,
		});
	}
}

function szafirDoTaskList(task, onSignatureVerified, onVerificationError) {
	console.log('szafirDoTaskList...');
	// eslint-disable-next-line no-undef
	SZAFIR_SDK.doTaskListNoWindow(
		task,
		result => handleSignatureVerified(result, onSignatureVerified, onVerificationError),
		error => handleError(error, onVerificationError)
	);
}

function generateSzafirVerifyTask(signatureB64, signatureId, archivePackageB64) {
	return `<?xml version="1.0" encoding="UTF-8"?>
	<TaskList><VerifyingTask><XAdESForm>XAdES-BES</XAdESForm>
	<PKCS7Form>PKCS#7</PKCS7Form>
	<VerifyingTaskItem><SignatureContainer><Base64Binary>${signatureB64}</Base64Binary>
	</SignatureContainer>
	<Signature Id="ID-c97bbd1d-f756-4c59-aca8-aa7cef24158b" URI="${signatureId}"><Format>XAdES-BES</Format>
	<SignedData>
	<Base64Binary>${archivePackageB64}</Base64Binary>
	</SignedData>
	<VerificationProperties><TimeSource><SystemTime></SystemTime>
	</TimeSource>
	</VerificationProperties>
	</Signature>
	</VerifyingTaskItem>
	</VerifyingTask>
	</TaskList>`;
}

function resolveNamespace(ns) {
	if (ns === 'ds') {
		return 'http://www.w3.org/2000/09/xmldsig#';
	} else {
		return null;
	}
}

function arrayBufferToBase64(buffer) {
	let binary = '';
	const bytes = new Uint8Array(buffer);
	const len = bytes.byteLength;
	for (let i = 0; i < len; i++) {
		binary += String.fromCharCode(bytes[i]);
	}
	return window.btoa(binary);
}

function configureSzafir(
	task,
	onSignatureVerified,
	onVerificationError,
	debug,
	devMode,
	devSzafirUri
) {
	console.log('configureSzafir...');
	// eslint-disable-next-line no-undef
	const SZAFIR = SZAFIR_SDK;

	SZAFIR.config({
		sdk_location_url: devMode ? `${devSzafirUri}/o/rest-api/szafir/` : '/o/rest-api/szafir/',
		versions_file: 'versions.xml',
		document_dependencies_folder: 'somewhere',
		series_authorization: true,
		onError: error => {
			console.log('szafirErrorCallback, error:', error);
			alert('[***** Błąd Szafir SDK *****]\n\n', error);
			if (onVerificationError) {
				onVerificationError(error);
			}
		},
		onErrorNoExtension: () => onVerificationError('noExtension'),
		onErrorNoHostApp: () => onVerificationError('noHostApp'),
		debug,
	});
	console.log('SZAFIR_SDK.version:', SZAFIR.version);
	console.log('SZAFIR_SDK.initialized', SZAFIR.isExtInitialized());
	initSzafirApplet(devMode, devSzafirUri);
	userLoadSzafir(task, onSignatureVerified, onVerificationError, devMode, devSzafirUri);
}

function initSzafirApplet(devMode, devSzafirUri) {
	// eslint-disable-next-line no-undef
	const SZAFIR = SZAFIR_SDK;
	if (SZAFIR.isModeApplet()) {
		const archive = devMode
			? `${devSzafirUri}/o/rest-api/szafir/cryptoapplet.jar`
			: 'o/rest-api/szafir/cryptoapplet.jar';
		const libDir = devMode ? `${devSzafirUri}/o/rest-api/szafir/` : '/o/rest-api/szafir';

		document.getElementById(
			'szafirApplet'
		).innerHTML = `${`<applet name="CA" code="pl.com.kir.crypto.applet.CryptoApplet" archive="${archive}" WIDTH="0" HEIGHT="0">\n` +
			'<param name="Server-Library" value="'}${libDir}"/>Your browser does not understand Java.</applet>`;
	}
}

function userLoadSzafir(task, onSignatureVerified, onVerificationError, devMode, devSzafirUri) {
	console.log('Start loading SZAFIR MODULE...');
	// eslint-disable-next-line no-undef
	SZAFIR_SDK.loadSzafir(
		() =>
			szafirStartComponentURI(
				task,
				onSignatureVerified,
				onVerificationError,
				devMode,
				devSzafirUri
			),
		error => handleError(error, onVerificationError)
	);
}

function szafirStartComponentURI(
	task,
	onSignatureVerified,
	onVerificationError,
	devMode,
	devSzafirUri
) {
	console.log('Start loading SZAFIR SETTINGS...4');
	// eslint-disable-next-line no-undef
	if ($('#SZAFIRSDK_APPLET_OBJECT').length > 0) {
		console.log('SZAFIR_SDK.mode: APPLET');
	} else {
		console.log('SZAFIR_SDK.mode: WEB-MODULE');
	}
	// eslint-disable-next-line max-len
	let settingsUri =
		'/o/rest-api/szafir/settings_files/settings_cryptoproviders_wszystkie_centra.xml';
	if (devMode) {
		settingsUri = `${devSzafirUri}${settingsUri}`;
	}
	// eslint-disable-next-line no-undef
	SZAFIR_SDK.startComponentURI(
		settingsUri,
		() => szafirDoTaskList(task, onSignatureVerified, onVerificationError),
		error => handleError(error, onVerificationError)
	);
}

export class NoSzafirExtDialog extends Component {
	constructor(props) {
		super(props);
	}

	hideNoEtxDialog(e) {
		const { onClose } = this.props;
		if (e !== undefined) {
			e.preventDefault();
		}
		if (onClose) {
			onClose();
		}
	}

	render() {
		const { visible } = this.props;
		const noExtDialogFooter = (
			<div>
				<Button label="Zamknij" icon="pi pi-check" onClick={e => this.hideNoEtxDialog(e)} />
			</div>
		);
		return (
			<Dialog
				ariaCloseIconLabel="Zamknij okno dialogowe"
				key="noExtDialog"
				visible={visible}
				style={{ width: '40vw' }}
				modal
				closable
				header="Ostrzeżenie - Brak rozszerzenia Szafir SDK"
				onHide={() => this.hideNoEtxDialog()}
				footer={noExtDialogFooter}
			>
				Niniejsza strona wykorzystuje komponenty podpisu elektronicznego&nbsp;
				<a tabIndex="0" href="http://elektronicznypodpis.pl/" target="_blank">
					Szafir SDK
				</a>
				&nbsp;
				<a tabIndex="0" href="http://www.kir.pl/" target="_blank">
					Krajowej Izby Rozliczeniowej S.A.
				</a>
				<br />W wersji dla przeglądarek <b>Google Chrome</b>, <b>Opera</b> i&nbsp;
				<b>Mozilla Firefox od wersji 52</b> wymagana jest instalacja dedykowanego rozszerzenia&nbsp;
				<b>Podpis elektroniczny Szafir SDK</b> oraz aplikacji udostępniającej funkcje podpisu
				elektronicznego.
				<p id="szafirsdk-link-buttons">
					<a
						tabIndex="0"
						id="szafirsdk-link-extension"
						// eslint-disable-next-line no-undef
						href={SZAFIR_SDK.getExtLink()}
						target="_blank"
					>
						Instalacja rozszerzenia z Web Store
					</a>
				</p>
				<div>
					<b>Uwaga:</b> Po zainstalowaniu rozszerzenia należy przeładować bieżącą stronę!
				</div>
			</Dialog>
		);
	}
}

NoSzafirExtDialog.defaultProps = {
	visible: false,
};

NoSzafirExtDialog.propTypes = {
	onClose: PropTypes.func.isRequired,
	visible: PropTypes.bool.isRequired,
};

export class NoSzafirHostDialog extends Component {
	constructor(props) {
		super(props);
	}

	hideNoHostDialog(e) {
		const { onClose } = this.props;
		if (e !== undefined) {
			e.preventDefault();
		}
		if (onClose) {
			onClose();
		}
	}

	render() {
		const { visible } = this.props;
		const noHostDialogFooter = (
			<div>
				<Button label="Zamknij" icon="pi pi-check" onClick={e => this.hideNoHostDialog(e)} />
			</div>
		);
		let appLinkWin = undefined;
		let appLinkLinux = undefined;
		// eslint-disable-next-line no-undef
		const SZAFIR = SZAFIR_SDK;
		if (SZAFIR.getAppLinks() !== undefined) {
			appLinkWin = SZAFIR.getAppLinks().windows;
			appLinkLinux = SZAFIR.getAppLinks().linux;
		}
		return (
			<Dialog
				ariaCloseIconLabel="Zamknij okno dialogowe"
				key="noHostDialog"
				visible={visible}
				style={{ width: '40vw' }}
				modal
				closable
				header="Ostrzeżenie - Brak aplikacji Szafir Host"
				onHide={() => this.hideNoHostDialog()}
				footer={noHostDialogFooter}
			>
				{!SZAFIR.isHostUpdateRequired() ? (
					<div id="szafirsdk-hostapp-install">
						Przeglądarka wymaga zainstalowania dedykowanej aplikacji&nbsp;
						<b>Szafir Host</b> umożliwiającej składanie podpisu elektronicznego.
					</div>
				) : null}

				{SZAFIR.isHostUpdateRequired() ? (
					<div id="szafirsdk-hostapp-update" style={{ color: 'Red' }}>
						Posiadasz nieaktualną wersję aplikacji <b>Szafir Host</b>&nbsp; używaną przez
						przeglądarkę do składania podpisu elektronicznego!!!
					</div>
				) : null}
				<p id="szafirsdk-nohost-link-buttons">
					<a tabIndex="0" style={{ maringBottom: '2px' }} href={appLinkWin} target="_blank">
						Pobierz Szafir Host dla Windows
					</a>
					<br />
					<a
						tabIndex="0"
						id="szafirsdk-link-installer-ux"
						href={appLinkLinux}
						style={{ maringBottom: '2px' }}
						target="_blank"
					>
						Pobierz Szafir Host dla Linux/Mac OS
					</a>
				</p>
				<div>
					<b>Uwaga:</b> Po zainstalowaniu aplikacji Szafir Host należy przeładować bieżącą stronę!
				</div>
				<div
					style={{ backgroundColor: '#78BED7', color: 'White', padding: '4px', marginTop: '4px' }}
				>
					Jeżeli aplikacja została prawidłowo zainstalowana i mimo tego nadal&nbsp; pojawia się
					niniejszy komunikat, należy sprawdzić czy na komputerze&nbsp; zainstalowane jest
					środowisko uruchomieniowe Java JRE.
					<br />
					Środowisko Java JRE można pobrać i zainstalować z lokalizacji:&nbsp;
					<a tabIndex="0" href="https://www.java.com/download/" target="_blank">
						Java JRE
					</a>
				</div>
			</Dialog>
		);
	}
}

NoSzafirHostDialog.defaultProps = {
	visible: false,
};

NoSzafirHostDialog.propTypes = {
	onClose: PropTypes.func.isRequired,
	visible: PropTypes.bool.isRequired,
};
